==> spambayes_1.0.3.orig.tar.gz: spambayes-1.0.3/Outlook2000/dialogs/resources/dialogs.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by dialogs.rc
//
#define IDD_MANAGER                     101
#define IDD_TRAINING                    102
#define IDD_FILTER                      103
#define IDD_FILTER_NOW                  104
#define IDD_FOLDER_SELECTOR             105
#define IDD_ADVANCED                    106
#define IDD_GENERAL                     108
#define IDD_FILTER_SPAM                 110
#define IDD_FILTER_UNSURE               111
#define IDD_DIAGNOSTIC                  113
#define IDD_WIZARD                      114
#define IDD_WIZARD_WELCOME              115
#define IDD_WIZARD_FINISHED_UNTRAINED   116
#define IDD_WIZARD_FOLDERS_REST         117
#define IDD_WIZARD_FOLDERS_WATCH        118
#define IDD_WIZARD_FINISHED_UNCONFIGURED 119
#define IDD_WIZARD_FOLDERS_TRAIN        120
#define IDD_WIZARD_TRAIN                121
#define IDD_WIZARD_FINISHED_TRAINED     122
#define IDD_WIZARD_TRAINING_IS_IMPORTANT 123
#define IDD_WIZARD_FINISHED_TRAIN_LATER 124
#define IDB_SBWIZLOGO                   125
#define IDB_FOLDERS                     127
#define IDC_PROGRESS                    1000
#define IDC_PROGRESS_TEXT               1001
#define IDC_STATIC_HAM                  1002
#define IDC_STATIC_SPAM                 1003
#define IDC_BROWSE_HAM                  1004
#define IDC_BROWSE_SPAM                 1005
#define IDC_START                       1006
#define IDC_BUT_REBUILD                 1007
#define IDC_BUT_RESCORE                 1008
#define IDC_VERSION                     1009
#define IDC_BUT_TRAIN_FROM_SPAM_FOLDER  1010
#define IDC_BUT_TRAIN_TO_SPAM_FOLDER    1011
#define IDC_BUT_TRAIN_NOW               1012
#define IDC_BUT_FILTER_ENABLE           1013
#define IDC_FILTER_STATUS               1014
#define IDC_BUT_FILTER_DEFINE           1016
#define IDC_BUT_ABOUT                   1017
#define IDC_BUT_ACT_SCORE               1018
#define IDC_BUT_ACT_ALL                 1019
#define IDC_BUT_UNREAD                  1020
#define IDC_BUT_UNSEEN                  1021
#define IDC_SLIDER_CERTAIN              1023
#define IDC_EDIT_CERTAIN                1024
#define IDC_ACTION_CERTAIN              1025
#define IDC_FOLDER_CERTAIN              1027
#define IDC_BROWSE_CERTAIN              1028
#define IDC_SLIDER_UNSURE               1029
#define IDC_EDIT_UNSURE                 1030
#define IDC_ACTION_UNSURE               1031
#define IDC_FOLDER_UNSURE               1033
#define IDC_BROWSE_UNSURE               1034
#define IDC_TRAINING_STATUS             1035
#define IDC_FOLDER_NAMES                1036
#define IDC_BROWSE                      1037
#define IDC_FOLDER_WATCH                1038
#define IDC_BROWSE_WATCH                1039
#define IDC_LIST_FOLDERS                1040
#define IDC_BUT_SEARCHSUB               1041
#define IDC_BUT_CLEARALL                1042
#define IDC_STATUS1                     1043
#define IDC_STATUS2                     1044
#define IDC_BUT_NEW                     1046
#define IDC_MARK_SPAM_AS_READ           1047
#define IDC_SAVE_SPAM_SCORE             1048
#define IDC_MARK_UNSURE_AS_READ         1051
#define IDC_DELAY1_SLIDER               1056
#define IDC_DELAY1_TEXT                 1057
#define IDC_DELAY2_SLIDER               1058
#define IDC_DELAY2_TEXT                 1059
#define IDC_INBOX_TIMER_ONLY            1060
#define IDC_VERBOSE_LOG                 1061
#define IDB_SBLOGO                      1062
#define IDC_LOGO_GRAPHIC                1063
#define IDC_TAB                         1068
#define IDC_BACK_BTN                    1069
#define IDC_BUT_WIZARD                  1070
#define IDC_SHOW_DATA_FOLDER            1071
#define IDC_ABOUT_BTN                   1072
#define IDC_BUT_RESET                   1073
#define IDC_DEL_SPAM_RS                 1074
#define IDC_RECOVER_RS                  1075
#define IDC_FORWARD_BTN                 1077
#define IDC_PAGE_PLACEHOLDER            1078
#define IDC_BUT_SHOW_DIAGNOSTICS        1080
#define IDC_BUT_PREPARATION             1081
#define IDC_FOLDER_HAM                  1083
#define IDC_BUT_UNTRAINED               1088
#define IDC_BUT_TRAIN                   1089
#define IDC_BUT_TIMER_ENABLED           1091
#define IDC_WIZ_GRAPHIC                 1092
#define IDC_BUT_VIEW_LOG                1093
#define IDC_EDIT1                       1094
#define IDC_STATISTICS                  1095

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        128
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1096
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> spambayes_1.1a6.orig.tar.gz: spambayes-1.1a6/Outlook2000/dialogs/resources/dialogs.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by dialogs.rc
//
#define IDD_MANAGER                     101
#define IDD_TRAINING                    102
#define IDD_FILTER                      103
#define IDD_FILTER_NOW                  104
#define IDD_FOLDER_SELECTOR             105
#define IDD_ADVANCED                    106
#define IDD_STATISTICS                  107
#define IDD_GENERAL                     108
#define IDD_FILTER_SPAM                 110
#define IDD_DIAGNOSTIC                  113
#define IDD_WIZARD                      114
#define IDD_WIZARD_WELCOME              115
#define IDD_WIZARD_FINISHED_UNTRAINED   116
#define IDD_WIZARD_FOLDERS_REST         117
#define IDD_WIZARD_FOLDERS_WATCH        118
#define IDD_WIZARD_FINISHED_UNCONFIGURED 119
#define IDD_WIZARD_FOLDERS_TRAIN        120
#define IDD_WIZARD_TRAIN                121
#define IDD_WIZARD_FINISHED_TRAINED     122
#define IDD_WIZARD_TRAINING_IS_IMPORTANT 123
#define IDD_WIZARD_FINISHED_TRAIN_LATER 124
#define IDB_SBWIZLOGO                   125
#define IDB_FOLDERS                     127
#define IDD_NOTIFICATIONS               128
#define IDC_PROGRESS                    1000
#define IDC_PROGRESS_TEXT               1001
#define IDC_STATIC_HAM                  1002
#define IDC_STATIC_SPAM                 1003
#define IDC_BROWSE_HAM                  1004
#define IDC_BROWSE_SPAM                 1005
#define IDC_START                       1006
#define IDC_BUT_REBUILD                 1007
#define IDC_BUT_RESCORE                 1008
#define IDC_VERSION                     1009
#define IDC_BUT_TRAIN_FROM_SPAM_FOLDER  1010
#define IDC_BUT_TRAIN_TO_SPAM_FOLDER    1011
#define IDC_BUT_TRAIN_NOW               1012
#define IDC_BUT_FILTER_ENABLE           1013
#define IDC_FILTER_STATUS               1014
#define IDC_BUT_FILTER_DEFINE           1016
#define IDC_BUT_ABOUT                   1017
#define IDC_BUT_ACT_SCORE               1018
#define IDC_BUT_ACT_ALL                 1019
#define IDC_BUT_UNREAD                  1020
#define IDC_BUT_UNSEEN                  1021
#define IDC_SLIDER_CERTAIN              1023
#define IDC_EDIT_CERTAIN                1024
#define IDC_ACTION_CERTAIN              1025
#define IDC_FOLDER_CERTAIN              1027
#define IDC_BROWSE_CERTAIN              1028
#define IDC_SLIDER_UNSURE               1029
#define IDC_EDIT_UNSURE                 1030
#define IDC_ACTION_UNSURE               1031
#define IDC_ACTION_HAM                  1032
#define IDC_FOLDER_UNSURE               1033
#define IDC_BROWSE_UNSURE               1034
#define IDC_TRAINING_STATUS             1035
#define IDC_FOLDER_NAMES                1036
#define IDC_BROWSE                      1037
#define IDC_FOLDER_WATCH                1038
#define IDC_BROWSE_WATCH                1039
#define IDC_LIST_FOLDERS                1040
#define IDC_BUT_SEARCHSUB               1041
#define IDC_BUT_CLEARALL                1042
#define IDC_STATUS1                     1043
#define IDC_STATUS2                     1044
#define IDC_BUT_NEW                     1046
#define IDC_MARK_SPAM_AS_READ           1047
#define IDC_SAVE_SPAM_SCORE             1048
#define IDC_MARK_UNSURE_AS_READ         1051
#define IDC_DELAY1_SLIDER               1056
#define IDC_DELAY1_TEXT                 1057
#define IDC_DELAY2_SLIDER               1058
#define IDC_DELAY2_TEXT                 1059
#define IDC_INBOX_TIMER_ONLY            1060
#define IDC_VERBOSE_LOG                 1061
#define IDB_SBLOGO                      1062
#define IDC_LOGO_GRAPHIC                1063
#define IDC_TAB                         1068
#define IDC_BACK_BTN                    1069
#define IDC_BUT_WIZARD                  1070
#define IDC_SHOW_DATA_FOLDER            1071
#define IDC_ABOUT_BTN                   1072
#define IDC_BUT_RESET                   1073
#define IDC_DEL_SPAM_RS                 1074
#define IDC_RECOVER_RS                  1075
#define IDC_FORWARD_BTN                 1077
#define IDC_PAGE_PLACEHOLDER            1078
#define IDC_BUT_SHOW_DIAGNOSTICS        1080
#define IDC_BUT_PREPARATION             1081
#define IDC_FOLDER_HAM                  1083
#define IDC_BUT_UNTRAINED               1088
#define IDC_BUT_TRAIN                   1089
#define IDC_BUT_TIMER_ENABLED           1091
#define IDC_WIZ_GRAPHIC                 1092
#define IDC_BUT_VIEW_LOG                1093
#define IDC_EDIT1                       1094
#define IDC_HAM_SOUND                   1094
#define IDC_STATISTICS                  1095
#define IDC_UNSURE_SOUND                1095
#define IDC_BUT_RESET_STATS             1096
#define IDC_SPAM_SOUND                  1096
#define IDC_LAST_RESET_DATE             1097
#define IDC_ENABLE_SOUNDS               1098
#define IDC_ACCUMULATE_DELAY_SLIDER     1099
#define IDC_ACCUMULATE_DELAY_TEXT       1100
#define IDC_BROWSE_HAM_SOUND            1101
#define IDC_BROWSE_UNSURE_SOUND         1102
#define IDC_BROWSE_HAM_SOUND2           1103
#define IDC_BROWSE_SPAM_SOUND           1103

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        129
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1102
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
